Documentation
¶
Index ¶
- Variables
- type Context
- type Dag
- func (currentDag *Dag) Append(dag *Dag)
- func (currentDag *Dag) ConditionalBranch(vertex string, conditions []string, condition sdk.Condition, options ...Option) (conditionDags map[string]*Dag)
- func (currentDag *Dag) Definition() (*sdk.DagExporter, error)
- func (currentDag *Dag) DefinitionJson() ([]byte, error)
- func (currentDag *Dag) Edge(from, to string, opts ...Option)
- func (currentDag *Dag) ForEachBranch(vertex string, foreach sdk.ForEach, options ...Option) (dag *Dag)
- func (currentDag *Dag) Node(vertex string, workload operation.Modifier, options ...Option) *Node
- func (currentDag *Dag) SubDag(vertex string, dag *Dag)
- func (currentDag *Dag) Validate() error
- type DataStore
- type ExecutionOptions
- type Node
- type Option
- type StateStore
- type Workflow
Constants ¶
This section is empty.
Variables ¶
var ( // Execution specify a edge doesn't forwards a data // but rather mention a execution direction Execution = InvokeEdge() )
Functions ¶
This section is empty.
Types ¶
type Dag ¶
type Dag struct {
// contains filtered or unexported fields
}
func (*Dag) Append ¶
Append generalizes a separate dag by appending its properties into current dag. Provided dag should be mutually exclusive
func (*Dag) ConditionalBranch ¶
func (currentDag *Dag) ConditionalBranch(vertex string, conditions []string, condition sdk.Condition, options ...Option) (conditionDags map[string]*Dag)
ConditionalBranch composites multiple dags as a sub-dag which executes for each conditions returned by the Condition function dynamically It returns the set of dags based on the set of condition passed
func (*Dag) Definition ¶
func (currentDag *Dag) Definition() (*sdk.DagExporter, error)
func (*Dag) DefinitionJson ¶
func (*Dag) ForEachBranch ¶
func (currentDag *Dag) ForEachBranch(vertex string, foreach sdk.ForEach, options ...Option) (dag *Dag)
ForEachBranch composites a sub-dag which executes for each value returned by ForEach function dynamically It returns the sub-dag that will be executed for each value
type ExecutionOptions ¶
type ExecutionOptions struct {
// contains filtered or unexported fields
}
ExecutionOptions options for branching in DAG
type Option ¶
type Option func(*ExecutionOptions)
func Aggregator ¶
func Aggregator(aggregator sdk.Aggregator) Option
Aggregator aggregates all outputs into one
func Forwarder ¶
Forwarder encodes request based on need for children vertex by default the data gets forwarded as it is
func InvokeEdge ¶
func InvokeEdge() Option
InvokeEdge denotes a edge doesn't forwards a data, but rather provides only an execution flow
func OnFailure ¶
func OnFailure(handler operation.FuncErrorHandler) Option
OnFailure Specify a function failure handler
type StateStore ¶
type StateStore sdk.StateStore
type Workflow ¶
type Workflow struct {
// contains filtered or unexported fields
}
func GetWorkflow ¶
GetWorkflow initiates a flow with a pipeline
func (*Workflow) Finally ¶
func (flow *Workflow) Finally(handler sdk.PipelineHandler)
Finally sets an execution finish handler routine it will be called once the execution has finished with state either Success/Failure
func (*Workflow) GetPipeline ¶
GetPipeline expose the underlying pipeline object
func (*Workflow) OnFailure ¶
func (flow *Workflow) OnFailure(handler sdk.PipelineErrorHandler)
OnFailure set a failure handler routine for the pipeline